@@ -1606,8 +1606,13 @@ get_user_info (void)
 
 	errno = 0;
 	pw = getpwuid (user.uid);
-	if (!pw && errno == 0)
-		die ("uid %d no longer exists", user.uid);
+	if (! pw) {
+		if (errno == 0) {
+			die ("uid %d no longer exists", user.uid);
+		}
+
+		die ("cannot determine user details for uid %d: %s", user.uid, strerror (errno));
+	}
 
 	p = memcpy (&user.passwd, pw, sizeof (struct passwd));
 	assert (p == (void *)&user.passwd);
@@ -4337,10 +4342,10 @@ format_time (const time_t *t, char *buffer, size_t len)
 		bug ("buffer too small");
 
 	/* Ensure nul byte copied */
-	strncpy (buffer, str, l+1);
+	strncpy (buffer, str, len);
 
 	/* Overwrite NL */
-	buffer[strlen (buffer)-1] = '\0';
+	buffer[strlen (str)-1] = '\0';
 }
 
 char *
